## <font style="background-color:#52C41A;"> </font> 功能说明
:::tips
<font style="color:black;">识别单号所属的快递公司</font>

:::

## <font style="background-color:#52C41A;"> </font> 接口信息
| **RequestType **<font style="color:#585A5A;">接口指令</font> | **<font style="color:#0070C0;">2002</font>** |
| :--- | :--- |
| **<font style="color:black;">批量请求</font>** | <font style="color:black;">不支持</font>，并发不超过10次/S |
| **<font style="color:black;">计费规则</font>** | <font style="color:black;">按请求成功</font>**<font style="color:black;">次数</font>**<font style="color:black;">计算。</font><font style="color:#8A8F8D;">当返回无结果（ Shippers=[</font><font style="color:#F1A2AB;"></font><font style="color:#8A8F8D;">] ）时，不计费</font> |
| **<font style="color:black;">接口地址</font>** | https://api.kdniao.com/api/dist |


## <font style="background-color:#52C41A;"> </font> 接口规则
:::color1
1.      接口只对快递单号进行识别，返回可能属于的一家或多家快递公司，实际归属哪家快递公司仍需用户判断

2.      识别失败，接口返回为空；如发现识别错误，请联系我们订正数据

3.      快递公司新上线的号段首次会识别失败；进行轨迹订阅并拉取到轨迹后，单号识别接口学习机制会完善此类单号的识别

:::

## <font style="background-color:#52C41A;"> </font> 支持情况
[单号识别支持的快递公司](https://www.yuque.com/kdnjishuzhichi/weubcu/yw4s6x1gbxsxadsp)



```json
{
     "LogisticCode": "3967950525457"
}
```

## <font style="background-color:#52C41A;"> </font> 应用级参数（RequestData）
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(</font>****<font style="color:#FFFFFF;">字符长度</font>****<font style="color:#FFFFFF;">)</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| :--- | :--- | :--- |
| LogisticCode | <font style="color:#8A8F8D;">String(30)</font> | 快递单号 |


## <font style="background-color:#52C41A;"> </font> 返回参数
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型(长度)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | :--- | --- | :--- |
| EBusinessID | <font style="color:#8A8F8D;">String(10)</font> | - [x]  | 用户ID |
| LogisticCode | <font style="color:#8A8F8D;">String(30)</font> | - [x]  | 快递单号 |
| Success | <font style="color:#8A8F8D;">Bool</font><font style="color:#8A8F8D;">(10)</font> | - [x]  | 成功与否(true/false) |
| <font style="color:rgb(0, 0, 0);">Reason</font> | <font style="color:#8A8F8D;">String(30)</font> | - [ ]  | 失败原因 |
| Shippers.<font style="color:#2A4200;">ShipperCode</font> | <font style="color:#8A8F8D;">String(10)</font> | - [ ]  | 快递公司编码 |
| Shippers.<font style="color:#2A4200;">ShipperName</font> | <font style="color:#8A8F8D;">String(30)</font> | - [ ]  | 快递公司名称 |


```json
{
      "EBusinessID": "1237100",
      "Success": true,
      "LogisticCode": "3967950525457",
      "Shippers": [
              {
                "ShipperCode": "YD",
                "ShipperName": "韵达速递"
              }
            ]
}
```

```json
{
	"LogisticCode"="312208599281014",
   "Shippers"=[
     {
		   "ShipperName"="韵达快递",
       "ShipperCode"="YD"
     },
     {
       "ShipperName"="加运美",
       "ShipperCode"="JYM"
     },
		 {
       "ShipperName"=null,
		   "ShipperCode"="AUEX"
	   }
   ],
  "EBusinessID"="1300000",
  "Code"= 100, 
  "Success"=true
}
```

:::danger
💡由于各快递公司单号生成规则独立，存在**<font style="color:#101E60;">一个单号规则命中多家快递</font>**的情况

若返回多结果，需用户侧人工判断

:::

